@@ -6,7 +6,7 @@
 
 int main(void) {
   const uint8_t pwd[]="shitty password";
-  const uint8_t secret[SPHINX_255_SCALAR_BYTES]={1};
+  const uint8_t secret[SPHINX_255_SCALAR_BYTES]={2};
   const uint8_t salt[crypto_pwhash_SALTBYTES]={1};
   uint8_t bfac[SPHINX_255_SCALAR_BYTES],
     chal[SPHINX_255_SER_BYTES],
@@ -17,7 +17,7 @@ int main(void) {
   if(0!=sphinx_respond(chal, secret, resp)) {
     return 1;
   }
-  if(0!=sphinx_finish(pwd, strlen((char*) pwd), bfac, resp, salt, rwd)) {
+  if(0!=sphinx_finish(pwd, strlen((char*) pwd), bfac, chal, resp, salt, rwd)) {
     return 1;
   }
 
